@@ -1,4 +1,9 @@
+# -*- coding: UTF-8 -*-
+# Copyright 2013-2022 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
+
 from lino.api import rt, dd, _
+from lino.core import constants
 
 rt.models.aids.GrantingsByClient.column_names = "detail_link request_date "\
                                       "aid_type category start_date"
@@ -7,15 +12,15 @@ notes = rt.models.notes
 notes.Note.hidden_elements = dd.fields_list(
     notes.Note, 'company contact_person contact_role')
 
-notes.NotesByProject.display_mode = "grid"
+notes.NotesByProject.display_mode = ((None, constants.DISPLAY_MODE_TABLE), )
 
-rt.models.uploads.UploadsByProject.display_mode = 'grid'
+rt.models.uploads.UploadsByProject.display_mode = ((None, constants.DISPLAY_MODE_TABLE), )
 
-rt.models.households.SiblingsByPerson.display_mode = 'grid'
+rt.models.households.SiblingsByPerson.display_mode = ((None, constants.DISPLAY_MODE_TABLE), )
 
-# rt.models.cal.TasksByController.display_mode = 'grid'
+# rt.models.cal.TasksByController.display_mode = ((None, constants.DISPLAY_MODE_TABLE), )
 
-# humanlinks.LinksByHuman.display_mode = 'grid'
+# humanlinks.LinksByHuman.display_mode = ((None, constants.DISPLAY_MODE_TABLE), )
 
 # ContactsByClient.column_names = 'company contact_person remark'
 # dd.update_field(ClientContact, 'remark', verbose_name=_("Contact details"))
